Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1234)

Unified Diff: chrome/browser/ui/views/payments/payment_request_sheet_controller.h

Issue 2695653004: [Web Payments] Add a mechanism to build item lists in the PR dialog. (Closed)
Patch Set: Fix up some comments. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/payments/payment_request_sheet_controller.h
diff --git a/chrome/browser/ui/views/payments/payment_request_sheet_controller.h b/chrome/browser/ui/views/payments/payment_request_sheet_controller.h
index d7c73e7f60f20b8224ca6e4684f44c2af80d1eeb..fbe3339ddb1ee6ac31ee8e5189301bd12d6fc9b3 100644
--- a/chrome/browser/ui/views/payments/payment_request_sheet_controller.h
+++ b/chrome/browser/ui/views/payments/payment_request_sheet_controller.h
@@ -55,6 +55,17 @@ class PaymentRequestSheetController : public views::VectorIconButtonDelegate {
// enabled state).
virtual std::unique_ptr<views::Button> CreatePrimaryButton();
+ // Creates and returns the view to be displayed next to the "Pay" and "Cancel"
+ // buttons. May return an empty std::unique_ptr (nullptr) to indicate that no
+ // extra view is to be displayed.The caller takes ownership of the view but
+ // the view is guaranteed to be outlived by the controller so subclasses may
+ // retain a raw pointer to the returned view (for example to control its
+ // enabled state).
+ // +---------------------------+
+ // | EXTRA VIEW | PAY | CANCEL |
+ // +---------------------------+
+ virtual std::unique_ptr<views::View> CreateExtraView();
Mathieu 2017/02/23 00:39:07 We should keep one of CreateExtraView or CreateLea
+
// views::VectorIconButtonDelegate:
void ButtonPressed(views::Button* sender, const ui::Event& event) override;
@@ -71,7 +82,7 @@ class PaymentRequestSheetController : public views::VectorIconButtonDelegate {
// | CONTENT |
// | VIEW |
// +---------------------------+
// | | CANCEL | PAY | <-- footer
// +---------------------------+
std::unique_ptr<views::View> CreatePaymentView(
std::unique_ptr<views::View> header_view,
@@ -71,7 +82,7 @@ class PaymentRequestSheetController : public views::VectorIconButtonDelegate {
// | VIEW |
// +---------------------------+
- // | | CANCEL | PAY | <-- footer
+ // | EXTRA VIEW | PAY | CANCEL | <-- footer
// +---------------------------+
std::unique_ptr<views::View> CreatePaymentView(

Powered by Google App Engine
This is Rietveld 408576698